@@ -19,8 +19,9 @@ import ipywidgets as widgets
 
 # Establece las variables globales
 # Código HTML para la pestaña de instrucciones 
-#instructions_html = None 
-
+instructions_html = None 
+with open('instructions.html', 'r') as file:
+    instructions_html = file.read()
 
 __DEBUG__ = False
 
@@ -619,8 +620,8 @@ def InteractTranspAL(mat1):
 # mat1: Lista de vectores en texto
 def InteractVectAL(mat1):
     try:
-        pares = po.ListaParesOrdenados(mat1)
-        po.graficarVectores(pares)
+        pares = ListaParesOrdenados(mat1)
+        graficarVectores(pares)
         return None
     except:
         if __DEBUG__:
@@ -1601,7 +1602,12 @@ def CVOperacion(operacion):
 # Autor: Carlos Alberto Trujillo
 def PresentarInterfaz():
     # Define las pestañas
-   
+    instructions_tab = widgets.HTMLMath(
+        value=instructions_html,
+        placeholder='',
+        description='',
+    )
+
     basicas_tab = widgets.Output()
 
     with basicas_tab:        
@@ -1654,7 +1660,7 @@ def PresentarInterfaz():
         interact(CVOperacion,operacion=dd_oper)    
 
     interface_tabs = widgets.Tab(
-        children=[basicas_tab,calculo_tab,algebra_tab, stats_tab, cvect_tab], _titles=tab_dict)
+        children=[instructions_tab,basicas_tab,calculo_tab,algebra_tab, stats_tab, cvect_tab], _titles=tab_dict)
 
     return interface_tabs
 
